

🚀 Ezalt
Módulo em python da planilha Ezalt de Richard Nakka
Feito por Lucas Valentim - UFABC Rocket Design

Tabela de conteúdos
Sobre o projeto
Funcionalidades
Como executar o projeto
Pré-requisitos
Instalando
Como contribuir no projeto
Licença
Sobre o projeto:

O projeto de iniciação científica modo pesquisando desde o primeiro dia (IC-PDPD) teve como objetivo a construção de um módulo em linguagem python das planilhas de Richard Nakka, foguetemodelista amador que constroi e junta dados desde a década de 70.

Durante seus anos de pesquisa, Nakka construiu diversas planilhas que possibilitam a construção de foguetes experimentais com maior facilidade.

Com base nisso, a construção desse projeto se baseia na sua planilha Ezalt, que calcula uma estimativa da performance de voo, entre outros dados.

Funcionalidades:

A ferramenta permite fazer os cálculos presentes na planilha de forma mais prática e permite a integração com outros programas em python.

O código aberto permite o uso de qualquer usuário e a adaptação do código como melhor agrada-lo. ---

Como executar o projeto:

Para a execução desse projeto, são necessários alguns pré-requisitos:

** -Pré-requisitos:**

Antes de começar, você vai precisar ter instalado em sua máquina os seguintes pacotes em python: math e datetime. Também é necessário ter instalado Python (https://www.python.org/downloads/) em seu computador. Siga os passo-a-passos para a instalação dos pacotes necessários, caso já não os possua.

** -Instalando:**

# Acesse o terminal/cmd

# Instalação pacote math $ pip install math

# Instalação datetime $ pip install datetime

Como contribuir no projeto:

Contribua para a melhoria desse código e ajude o setor aeroespacial! Modifique, atualize e entre em contato.

--- Autor: Lucas Valentim

LinkedIn: https://www.linkedin.com/in/lucasvalentimb/

Gmail: lucasbcamara@gmail.com

--- Licença:

Este projeto esta sobe a licença [MIT](./LICENSE).